
The ``nlpsig`` Python package
=============================

``nlpsig``
------------

The ``nlpsig`` library provides functionality for constructing paths of embeddings obtained using transformer models.
It also provides an interface to popular dimensionality reduction techniques such as UMAP and Random projections.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: API
   :glob:

   encode_text.rst
   data_preparation.rst
   dimensionality_reduction.rst
   classification_utils.rst

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: About
   :glob:

   authors.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
